package com.persagy.legend.services

import com.persagy.legend.models.entities.LegendIcon
import com.sybotan.database.SFilter
import com.sybotan.mybatis.SMybatisDao
import com.sybotan.service.SObjectService
import com.sybotan.service.models.enums.SResponseType
import com.sybotan.service.models.requests.SQueryRequest
import com.sybotan.service.models.responses.SCreateResponse
import com.sybotan.service.models.responses.SQueryResponse
import java.util.*

/**
 * @author  zy
 */
object LegendIconService : SObjectService<LegendIcon>(SMybatisDao(LegendIcon::class.java)) {
    /**
     * 保存
     *
     * @param legend     图标图例对象
     * @return 返回结果
     */
    fun save(legend: LegendIcon): SCreateResponse<LegendIcon> {
        /** 返回对象 */
        val sCreateResponse = SCreateResponse<LegendIcon>()
        return try {
            /** id 为空赋值 */
            if (legend.id.isNullOrEmpty()) {
                legend.id = UUID.randomUUID().toString().replace("-", "")
            }

            /** 插入数据 */
            val insert = LegendIconService.replace(legend)
            if (!insert){
                sCreateResponse.result = SResponseType.failure
                return sCreateResponse
            }

            /** 状态 */
            /** 清空图例相关的状态 */
            LegendStateService.delete(SFilter.eq("legendId", legend.id!!))
            /** 插入图例相关的状态 */
            if (!legend.stateList.isNullOrEmpty()) {
                val stateList = legend.stateList
                /** 遍历状态 */
                for (state in stateList!!){
                    /** 图例 id */
                    state!!.legendId = legend.id
                    if (state.id.isNullOrEmpty()) {
                        state.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    /** 插入数据 */
                    LegendStateService.replace(state)
                }
            }
            /** 对象列表 */
            sCreateResponse.entityList = arrayListOf(legend)
            /** 标志 */
            sCreateResponse.result = SResponseType.success
            /** 对象 */
            sCreateResponse
        } catch (e: Exception) {
            e.printStackTrace()
            sCreateResponse.result = SResponseType.failure
            sCreateResponse
        }
    }

    override fun onDeleteSuccess(entityList: ArrayList<LegendIcon>) {
        super.onDeleteSuccess(entityList)
        for (entity in entityList) {
            LegendStateService.delete(SFilter.eq("legendId", entity.id!!))
        }
    }

    /**
     * 查询默认状态的图例
     *
     * @param  request  查询条件
     * @return 返回结果
     */
    fun statePageQuery(request: SQueryRequest): SQueryResponse<LegendIcon> {
        val pageQuery = pageQuery(request)
        if (pageQuery.result == SResponseType.success) {
         if (!pageQuery.content.isNullOrEmpty()) {
          for (content in pageQuery.content!!) {
              val entity =
                  LegendStateService.select(SFilter.eq("legendId", content.id!!), SFilter.eq("state", content.state!!))
                      .entity()
              if (entity!=null) {
                  content.stateList = arrayListOf(entity)
              }
            }
          }
        }
        return pageQuery
    }
}